@@ -46,6 +46,8 @@ def informUser  ( msg
     for i in range(marginBot): print()
     return None
 
+####################################################################################################################################
+
 def note( msg
         , methodName = ""
         , newLine = "\n"
@@ -62,6 +64,8 @@ def note( msg
                 )
     return None
 
+####################################################################################################################################
+
 def warn( msg
         , methodName = ""
         , newLine = "\n"
@@ -78,6 +82,8 @@ def warn( msg
                 )
     return None
 
+####################################################################################################################################
+
 def abort   ( msg
             , methodName = ""
             , newLine = "\n"
@@ -92,6 +98,6 @@ def abort   ( msg
                 , marginBot = marginBot
                 , end = end
                 )
-    import sys as _sys
-    _sys.exit()
-    return None
+    raise Exception( "Fatal error occurred. Gracefully exiting." )
+
+####################################################################################################################################
