@@ -48,6 +48,6 @@ LOG_SMVN_COEF = NDIM * np.log( 1.0 / np.sqrt(2.0*np.pi) )
 
 #def getLogFunc_pntr(ndim,Point): return LOG_SMVN_COEF - 0.5 * np.sum( np.double( Point[0:ndim[0]] )**2 )
 
-def getLogFunc_pntr(ndim,Point): return LOG_SMVN_COEF - 0.5 * np.sum( np.double( Point[0:ndim] )**2 )
+def getLogFuncRaw(ndim,Point): return LOG_SMVN_COEF - 0.5 * np.sum( np.double( Point[0:ndim] )**2 )
 
 def getLogFunc(Point): return LOG_SMVN_COEF - 0.5 * np.sum( np.double( Point )**2 )
